@@ -91,25 +91,25 @@
 ## @end table
 ##
 ## Output:
-## @var{retval} = 0: only spreadsheet read support for OOXML,
-## ODS 1.2 and gnumeric present through OCT interface, or
+## @var{retval} = 0: only spreadsheet support for OOXML & ODS 1.2
+## and read support for gnumeric present through OCT interface, or
 ## @var{retval} <> 0: At least one read/write spreadsheet I/O
-## interface found.
+## interface found based on external software.
 ## RETVAL will be set to the sum of values for found interfaces:
 ## @example
 ##     0 = OCT (Native Octave)
-##         (only read support for .xlsx, .ods and .gnumeric)
-##    ---------- XLS (Excel) interfaces: ----------
+##         (read/write support for .xlsx and .ods, read support for .gnumeric)
+##   ----------- XLS (Excel) interfaces: ----------
 ##     1 = COM (ActiveX / Excel) (any file format supported by MS-Excel)
 ##     2 = POI (Java / Apache POI) (Excel 97-2003 = BIFF8)
 ##     4 = POI+OOXML (Java / Apache POI) (Excel 2007-2010 = OOXML)
 ##     8 = JXL (Java / JExcelAPI) (Excel 95-read and Excel-97-2003-r/w)
 ##    16 = OXS (Java / OpenXLS) (Excel 97-2003)
-##    --- ODS (OpenOffice.org Calc) interfaces ----
+##   ---- ODS (OpenOffice.org Calc) interfaces ----
 ##    32 = OTK (Java/ ODF Toolkit) (ODS 1.2)
 ##    64 = JOD (Java / jOpenDocument) (.sxc (old OOo)-read, ODS 1.2)
-##    ----------------- XLS & ODS: ----------------
-##     0 = OOXML / ODS / gumeric read support (built-in)
+##   ------------------ XLS & ODS: ----------------
+##     0 = OOXML / ODS read/write-, gnumeric read support (built-in)
 ##   128 = UNO (Java/UNO bridge - OpenOffice.org) (any format supported by OOo)
 ## @end example
 ##
@@ -167,12 +167,19 @@
 ## 2014-01-07 Style fixes; "forward slash expected" message conditional on dbug
 ## 2014-01-08 Keep track of loaded jars; allow unloading them; return them as output arg
 ##     ''     Return checked interfaces; update texinfo header
+## 2014-01-17 Tame messages about COM/ActiveX if dbug = 0
+## 2014-04-06 Skip unojarpath search for UNO entries 4 and up; code style fixes
+## 2014-04-14 Updated texinfo header & OCT r/w support messages
+## 2014-04-15 More updates to texinfo header
+## 2014-04-26 Check for built-in Java support before trying to handle Java stuff
+##     ''     Cleaned up various messages
 
 function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_to_jars, dbug, path_to_ooo)
 
   ## Keep track of which Java class libs were loaded
-  persistent loaded_jars;
-  persistent sinterfaces;
+  persistent loaded_jars;                   ## Java .jar class libs added to
+                                            ## javaclasspath by this func
+  persistent sinterfaces;                   ## Interfaces found to be supported
 
   sinterfaces = {"OCT"};
   jcp = []; 
@@ -214,9 +221,14 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
   interfaces = {"COM", "POI", "POI+OOXML", "JXL", "OXS", "OTK", "JOD", "UNO", "OCT"}; 
   ## Order  = vital
 
+  ## Just mention OCT interface
+  if (dbug > 1)
+    printf ("(OCT interface... OK, included in io package)\n\n");
+  endif
+
   ## Check if MS-Excel COM ActiveX server runs. Only needed on Windows systems
   if (ispc)
-    if (dbug)
+    if (dbug >= 1)
       printf ("Checking Excel/ActiveX/COM... ");
     endif
     try
@@ -226,14 +238,14 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
       ## Close Excel to avoid zombie Excel invocation
       app.Quit();
       delete(app);
-      if (dbug)
+      if (dbug >= 1)
         printf ("OK.\n\n");
       endif
       retval = retval + 1;
       sinterfaces = [ sinterfaces, "COM" ];
     catch
       ## COM not supported
-      if (dbug)
+      if (dbug >= 1)
         printf ("not working.\n");
       endif
       ## Check if Windows package is installed and loaded
@@ -241,22 +253,38 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
       winpkgind = find (cellfun (@(x) strcmp(x.name, "windows"), pkglist), 1, "first");
       if (! isempty (winpkgind))
         winpkg = pkglist{winpkgind};
-        if (winpkg.loaded)
-          printf ("MS-Excel couldn't be started (maybe because of 64-bit MS-Office?)\n");
+        if (winpkg.loaded && dbug)
+          printf ("MS-Excel couldn't be started although OF windows is loaded...\n");
         endif
-      else
-        printf ("(windows package is required for COM/ActiveX support)\n");
+      elseif (dbug >= 1)
+        printf ("(OF windows package is required for COM/ActiveX support)\n");
       endif
       printf ("\n");
     end_try_catch
   endif
 
   ## Check Java
-  if (dbug)
-    printf ("Checking Java support...\n");
+  if (dbug > 1)
+    printf ("1. Checking Octave's Java support... ");
+  endif
+  if (! octave_config_info.features.JAVA)
+    ## Nothing to do here anymore
+    if (abs (dbug) > 1)
+      printf ("none.\nThis Octave has no built-in Java support. Skipping Java checks\n");
+      if (! retval)
+        printf ("Only ODS 1.2 (.ods) & OOXML (.xlsx) r/w support & .gnumeric read support present\n");
+      endif
+    endif
+    return
+  elseif (dbug > 1)
+    printf ("OK.\n");
+  endif
+
+  if (dbug > 1)
+    printf ("2. Checking Java dependencies...\n");
   endif
   if (dbug > 1)
-    printf ("  1. Checking Java JRE presence.... ");
+    printf ("  Checking Java JRE presence.... ");
   endif
   ## Try if Java is installed at all
   if (ispc)
@@ -269,7 +297,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     if (jtst)
       printf ("Apparently no Java JRE installed.\n");
       if (! retval)
-        printf ("Only read support for ODS 1.2 (.ods), OOXML (.xlsx) and .gnumeric present\n");
+        printf ("\nOnly ODS 1.2 (.ods) & OOXML (.xlsx) r/w support & .gnumeric read support present\n");
       endif
       return;
     else
@@ -277,45 +305,9 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
         printf ("OK, found one.\n");
       endif
     endif
-    if (dbug > 1)
-      printf ("  2. Checking Octave Java support... ");
-    endif
   endif
-  ## Check core Java support (newer Octave)
   try
-    ## The following stanza is meant for older Octave w/o built-in Java
-    if (compare_versions (OCTAVE_VERSION, "3.7.2", "<"))
-      ## Check Java package
-      [~, b] = pkg ("describe", "java");
-      if (strcmpi (b{:}, "Not loaded"))
-        if (dbug > 1)
-          printf ('Java package found but not loaded. First do: "pkg load java"\n');
-        endif
-      elseif strcmpi (b{:}, "Not installed")
-        if (dbug > 1)
-          printf ("Java package is not installed.\n");
-        endif
-      endif
-    else
-      ## Check for proper look of UGLY_DEFS/features (only needed for 3.7.2+ version)
-      if (isfield (octave_config_info, "features"))
-        if (! octave_config_info.features.JAVA)
-          if (dbug)
-            printf ("none.\n");
-            printf ("     (Octave was built without core Java support)\n");
-          endif
-        endif
-      elseif (isfield (octave_config_info, "UGLY_DEFS"))
-        if (isempty (regexp (octave_config_info.UGLY_DEFS, "HAVE_JAVE=1", "match")))
-          if (dbug)
-            printf ("none.\n");
-            printf ("     (Octave was built without enabled core Java support)\n");
-          endif
-        endif
-      endif
-    endif
-
-    ## OK sufficient info to give it a try
+    ## OK sufficient info to investigate further
     [tmp1, jcp] = __chk_java_sprt__ (dbug);
 
     if (tmp1)
@@ -332,31 +324,28 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
         if (jmem < 400)
           printf ("should better be at least 400 MB!\n");
           printf ('    Hint: adapt setting -Xmx in file "java.opts" (supposed to be here:)\n');
-          printf ("    %s\n", [matlabroot filesep "share" filesep "octave" filesep "packages" filesep "java-<version>" filesep "java.opts"]);
+          printf ("    %s\n", [matlabroot filesep "share" filesep "octave" filesep "packages" filesep "java-<version>" filesep "java.opts\n"]);
         else
           printf ("sufficient.\n");
         endif
       endif
-      if (dbug)
-        printf ("Java support OK\n");
-      endif
     endif
   catch
     ## No Java support
   end_try_catch
   if (! tmp1)
     ## We can return as for below code Java is required.
-    if (dbug)
+    if (dbug > 1)
       printf ("No Java support found.\n");
       if (! retval)
-        printf ("Only read support for ODS 1.2 (.ods), OOXML (.xlsx) and .gnumeric\n");
+        printf ("Only ODS 1.2 (.ods) & OOXML (.xlsx) r/w support & .gnumeric read support present\n");
       endif
     endif
     return
   endif
 
   if (dbug)
-    printf ("\nChecking javaclasspath for .jar class libraries needed for spreadsheet I/O...:\n");
+    printf ("Checking javaclasspath for .jar class libraries needed for spreadsheet I/O...:\n");
   endif
 
   ## Try Java & Apache POI. First Check basic .xls (BIFF8) support
@@ -442,7 +431,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
       endif
     catch
       ## Wrong OpenXLS.jar version (probably <= 6.08). V. 10 is required now
-      warning ("OpenXLS.jar version is outdated; please upgrade to v.10");
+      warning ("OpenXLS.jar version is outdated; please upgrade to v.10\n");
     end_try_catch
   endif
 
@@ -530,7 +519,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
       return;
     endif
     if (dbug && ! isempty (strfind (path_to_ooo, '\')))
-      printf ("\n(Hmmm... forward slashes are preferred over backward slashes in path)\n");
+      printf ("\n(forward slashes are preferred over backward slashes in path)\n");
     endif
     ## Add missing jars to javaclasspath. First combine all entries
     targt = sum (missing0);
@@ -602,13 +591,16 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
           file = dir ([ unojarpath filesep entries0{2} "*" ]);
         else
           ## Rest of jars in ./ure/share/java or ./ure/java
-          unojardir = get_dir_ (uredir, "share");
-          if (isempty (unojardir))
-            tmp = uredir;
-          else
-            tmp = unojardir;
+          if (ii == 3)
+            ## Find unojarpath; the rest of the entries should live here too
+            unojardir = get_dir_ (uredir, "share");
+            if (isempty (unojardir))
+              tmp = uredir;
+            else
+              tmp = unojardir;
+            endif
+            unojarpath = get_dir_ (tmp, "java");
           endif
-          unojarpath = get_dir_ (tmp, "java");
           file = dir ([unojarpath filesep entries0{ii} "*"]);
         endif
         ## Path found, now try to add jar
@@ -639,7 +631,9 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
         endif
       endif
     endfor
+    ## Check if all entries have been found
     if (! targt)
+      ## Yep
       retval = retval + 128;
       sinterfaces = [sinterfaces, "UNO"];
     endif
@@ -666,7 +660,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
 
   if (! jars_complete && nargin > 0 && ! isempty (path_to_jars))
     ## Add missing jars to javaclasspath. Assume they're all in the same place
-    ## FIXME: add checks for prope odfdom && OpenXLS jar versions
+    ## FIXME: add checks for proper odfdom && OpenXLS jar versions
     if (dbug)
       printf ("Trying to add missing java class libs to javaclasspath...\n");
     endif
@@ -743,7 +737,9 @@ function [ ret_dir ] = get_dir_ (base_dir, req_dir)
     ii = 1;
     while (! ret_dir_list(idx(ii)).isdir)
       ii = ii + 1;
-      if (ii > numel (idx)); return; endif
+      if (ii > numel (idx))
+        return; 
+      endif
     endwhile
     ## If we get here, a dir with proper name has been found. Construct path
     ret_dir = [ base_dir filesep  ret_dir_list(idx(ii)).name ];
