@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013 Philip Nienhuis
+## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -19,8 +19,8 @@
 ## @deftypefnx {Function File} [ @var{ods}, @var{rstatus} ] = oct2ods (@var{arr}, @var{ods}, @var{wsh}, @var{range})
 ## @deftypefnx {Function File} [ @var{ods}, @var{rstatus} ] = oct2ods (@var{arr}, @var{ods}, @var{wsh}, @var{range}, @var{options})
 ##
-## Transfer data to an OpenOffice_org Calc spreadsheet previously opened
-## by odsopen().
+## Transfer data to an OpenOffice_org Calc (or gnumeric) spreadsheet
+## previously opened by odsopen().
 ##
 ## Data in 1D/2D array @var{arr} are transferred into a cell range
 ## @var{range} in sheet @var{wsh}. @var{ods} must have been made earlier
@@ -121,6 +121,7 @@
 ## 2012-10-24 Style fixes
 ## 2012-12-18 Improved error/warning messages
 ## 2013-12-18 Copyright string updates, style fixes
+## 2014-03-18 Add back in UNO interface (changed into by OCT - blush)
 ##
 ## Latest subfunc update: 2012-10-12
 
@@ -140,7 +141,7 @@ function [ ods, rstatus ] = oct2ods (c_arr, ods, wsh=1, crange="", spsh_opts=[])
   elseif (ischar(c_arr))
     c_arr = {c_arr};
     printf ("(oct2ods: input character array converted to 1x1 cell)\n");
-  elseif (~iscell (c_arr))
+  elseif (! iscell (c_arr))
     error ("oct2ods: input array neither cell nor numeric array");
   endif
   if (ndims (c_arr) > 2)
@@ -202,9 +203,13 @@ function [ ods, rstatus ] = oct2ods (c_arr, ods, wsh=1, crange="", spsh_opts=[])
     [ ods, rstatus ] = __JOD_oct2spsh__ (c_arr, ods, wsh, crange);
 
   elseif (strcmp (ods.xtype, "UNO"))
-    ## Write ods file tru Java & UNO bridge (OpenOffice.org & clones)
+    ## Write ods file tru UNO
     [ ods, rstatus ] = __UNO_oct2spsh__ (c_arr, ods, wsh, crange, spsh_opts);
 
+  elseif (strcmp (ods.xtype, "OCT"))
+    ## Write ods or gnumeric file tru native Octave
+    [ ods, rstatus ] = __OCT_oct2spsh__ (c_arr, ods, wsh, crange, spsh_opts);
+
   ##elseif 
     ##---- < Other interfaces here >
 
@@ -213,6 +218,8 @@ function [ ods, rstatus ] = oct2ods (c_arr, ods, wsh=1, crange="", spsh_opts=[])
                     ods.xtype));
   endif
 
-  if (rstatus), ods.limits = []; endif
+  if (rstatus)
+    ods.limits = [];
+  endif
 
 endfunction
