@@ -1,4 +1,5 @@
 // Copyright (C) 2004 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2014 Philip Nienhuis <prnienhuis@users.sf.net>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -39,6 +40,7 @@
 %! s = csv2cell(f);
 %! unlink (f);
 %! assert (s{1}, 3);
+
 %! assert (s{2}, "1");
 
 %% Check proper string protection
@@ -58,7 +60,7 @@
 %! assert (ddd, 31.0, 1e-5);
 %! assert (iscellstr (s(1:4, 2)), true);
 %! assert (isnumeric ([s{1, 3} s{3:4, 3}]), true);
-%1 assert (ischar (s{2, 3}), true);
+%! assert (ischar (s{2, 3}), true);
 
 %% Check separator and string protection arguments
 %!test
@@ -77,14 +79,46 @@
 %! assert (ddd, 31.0, 1e-5);
 %! assert (iscellstr (s(1:4, 2)), true);
 %! assert (isnumeric ([s{1, 3} s{3:4, 3}]), true);
-%1 assert (ischar (s{2, 3}), true);
+%! assert (ischar (s{2, 3}), true);
+
+%% Check headerlines,
+%!test
+%! f = tmpnam ();
+%! fid = fopen (f, 'w+');
+%! fprintf (fid, "A, B\n 1, 2\n 3, 4\n 5, 6\n");
+%! fclose (fid);
+%! s = csv2cell (f);
+%! assert (iscellstr (s(1, :)), true);
+%! assert (cell2mat (s(2:end, :)), [1 2; 3 4; 5 6], 1e-10);
+%! s = csv2cell (f, 1);
+%! assert (cell2mat (s), [1 2; 3 4; 5 6], 1e-10);
+%! s = csv2cell (f, 3);
+%! assert (cell2mat (s), [5 6], 1e-10);
+%! s = csv2cell (f, -3);
+%! assert (iscellstr (s(1, :)), true);
+%! assert (cell2mat (s(2:end, :)), [1 2; 3 4; 5 6], 1e-10);
+%! s = csv2cell (f, 5);
+%! assert (iscell (s) && isempty (s));
+%! unlink (f);
+
+%% Check surplus headerlines w EOF before final EOL
+%!test
+%! f = tmpnam ();
+%! fid = fopen (f, 'w+');
+%! fprintf (fid, "A, B\n 1, 2\n 3, 4\n 5, 6");
+%! fclose (fid);
+%! s = csv2cell (f, 10);
+%! unlink (f);
+%! assert (iscell (s) && isempty (s));
 
 */
 
 #include <fstream>
+#include <iostream>
 
 #include <octave/oct.h>
 #include <octave/Cell.h>
+#include <octave/ov.h>
 
 #define MAXSTRINGLENGTH 4096
 
@@ -93,13 +127,19 @@ DEFUN_DLD (csv2cell, args, nargout,
           "@deftypefn {Loadable Function} {@var{c} = } csv2cell (@var{file})\n"
        "@deftypefnx {Loadable Function} {@var{c} = } csv2cell (@var{file}, @var{sep})\n"
        "@deftypefnx {Loadable Function} {@var{c} = } csv2cell (@var{file}, @var{sep}, @var{prot})\n"
+       "@deftypefnx {Loadable Function} {@var{c} = } csv2cell (@var{file}, @var{hl}, ...)\n"
        "\n"
-       "Read a CSV (Comma Separated Values) file and convert it into a cell array. "
-       "@var{sep} (a character value) changes the character used to separate two fields. "
-       "The default value is a comma "
-       "(@code{,}). @var{prot} (character value) changes the character used to protect a string. "
-       "The default is a double quote (@code{\"}).\n"
-       "The maximum line width of the csv file is 4092 characters.\n"
+       "Read a CSV (Comma Separated Values) file and convert it into a cell "
+       "array. "
+       "@var{sep} (a character value) changes the character used to separate "
+       "two fields. The default value is a comma (@code{,}). "
+       "@var{prot} (a character value) changes the character used to protect "
+       "a string. The default is a double quote (@code{\"}).\n"
+       "Optional argument @var{hl} (a numeric value >= 0) is the number of "
+       "headerlines to skip; negative values are ignored. If @var{hl} is "
+       "equal to or larger than the total number of lines in the file, no "
+       "data are read and an empty cell array is returned. "
+       "The maximum line width of the csv file is 4096 characters.\n"
        "@end deftypefn") {
 
   /* Get arguments */
@@ -113,7 +153,11 @@ DEFUN_DLD (csv2cell, args, nargout,
     
   const std::string file = args (0).string_value ();
 
-  const std::string _sep = (nargin > 1) ? args(1).string_value () : ",";
+  /* Look if first arg after filename = numeric. If yes => headerlines */
+  const long hlines = (nargin > 1 && args(1).is_numeric_type () ? args(1).long_value() : 0);
+  const int arg_sh = (nargin > 1 && args(1).is_numeric_type () ? 1 : 0);
+
+  const std::string _sep = (nargin > arg_sh + 1) ? args(arg_sh + 1).string_value () : ",";
   if (_sep.length() != 1)
     {
       error ("csv2cell: separator value can only be one character\n");
@@ -121,7 +165,7 @@ DEFUN_DLD (csv2cell, args, nargout,
     }
   char sep = _sep[0];
 
-  const std::string _prot = (nargin > 2) ? args(2).string_value () : "\"";
+  const std::string _prot = (nargin > arg_sh + 2) ? args(arg_sh + 2).string_value () : "\"";
   if (_prot.length() != 1)
     {
       error ("csv2cell: protector value can be only one character\n");
@@ -148,7 +192,15 @@ DEFUN_DLD (csv2cell, args, nargout,
   std::string str, word;
   bool inside = false;
 
-  /* Read a line */
+  /* Read headerlines */
+  for (long ii=0; ii < hlines; ii++)
+  {
+    fd.getline (line, MAXSTRINGLENGTH);
+    if (fd.tellg () >= fdend || fd.fail ())
+      return octave_value (Cell (0, 0));
+  }
+
+  /* Read a first data line */
   str = "";
   fd.getline (line, MAXSTRINGLENGTH);
   while (fd.fail ())
@@ -171,7 +223,7 @@ DEFUN_DLD (csv2cell, args, nargout,
       inside = !inside;
 
   /* Read all the file to get number of rows */
-  int nbrows = 1;
+  long nbrows = 1;
   while (fd.tellg () <= fdend && fd.peek () != EOF)
     {
       fd.getline (line, MAXSTRINGLENGTH);
@@ -192,9 +244,15 @@ DEFUN_DLD (csv2cell, args, nargout,
       return retval;
     }
 
+  /* Again, read headerlines */
+  for (long ii = 0; ii < hlines; ii++)
+  {
+    fd.getline (line, MAXSTRINGLENGTH);
+  }
+
   /* Read all the file until the end */
   Cell c (nbrows, nbcolumns);
-  for (int i = 0; i < nbrows; i++)
+  for (long i = 0; i < nbrows; i++)
     {
       /* Read a line */
       str = "";
